@@ -51,22 +51,21 @@ class Request:
     #: :class:`.Session` for queries sent from the instance.
     session = None
 
-    def __init__(self, source=None, log_level=None, 
-            session=None, **session_opts):
+    def __init__(self, source=None, log_level=None, session=None, **session_opts):
         """Constructor."""
         try:
             self.source = sources[source.upper()] if source else NoSource
         except KeyError:
-            raise ValueError('source must be None or one of: %s' %
-                             ' '.join(list_sources()))
+            raise ValueError(
+                "source must be None or one of: %s" % " ".join(list_sources())
+            )
 
         if session and session_opts:
-            raise TypeError('When `session` is given, `session_opts` must be  empty.')
-        self.session = (session or 
-            remote.Session(**session_opts))
+            raise TypeError("When `session` is given, `session_opts` must be  empty.")
+        self.session = session or remote.Session(**session_opts)
 
         if log_level:
-            logging.getLogger('pandasdmx').setLevel(log_level)
+            logging.getLogger("pandasdmx").setLevel(log_level)
 
     def __getattr__(self, name):
         """Convenience methods."""
@@ -76,7 +75,7 @@ class Request:
             # resource_id
             func = partial(self.get, Resource[name])
         except KeyError:
-            raise AttributeError
+            raise AttributeError(name)
         else:
             # Modify the docstring to explain the argument fixed by the
             # convenience method
@@ -89,6 +88,21 @@ class Request:
         """Include convenience methods in dir()."""
         return super().__dir__() + [ep.name for ep in Resource]
 
+    def view_doc(self):
+        """
+        Open documentation website of the data source, if given, in a new browser tab.
+        Otherwise, raise RuntimeError.
+        """
+        url = self.source.documentation
+        if url:
+            import webbrowser as wb
+
+            wb.open_new_tab(url)
+        else:
+            raise RuntimeError(
+                f"No documentation URL given for data source {self.source.id}."
+            )
+
     def clear_cache(self):
         self.cache.clear()
 
